Installation
============

.. tab-set::

    .. tab-item:: pip

        .. code-block:: sh

            pip install scitacean[ssh]

        If :class:`scitacean.transfer.ssh.SSHFileTransfer` is not required, the ``ssh`` extra can be omitted.

    .. tab-item:: conda

        .. code-block:: sh

            conda install -c conda-forge scitacean

